#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://avidemux.org/
# source location    : http://download2.berlios.de/avidemux/avidemux_2.5.6.tar.gz
# last revised       : 2.1.2012
# dep                : 

softname='avidemux'
softversion='2.5.6'
packageversion='72.1'

arch='i486'
cpu='i686'

prefix=/usr

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname"_"$softversion"
srcpkg="$buildir/$softname"_"$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://download2.berlios.de/avidemux/"$softname"_"$softversion".tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
        |-----handy-ruler------------------------------------------------------|
avidemux: avidemux - a small and efficient video editor
avidemux:
avidemux: Avidemux is a free video editor designed for simple cutting, filtering
avidemux: and encoding tasks. It supports many file types, including AVI, DVD
avidemux: compatible MPEG files, MP4 and ASF, using a variety of codecs. Tasks
avidemux: can be automated using projects, job queue and powerful scripting
avidemux: capabilities.
avidemux:
avidemux:
avidemux:
avidemux:
EOF

# check if source is present
if [ -f $softname_$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

#rm CMakeCache.txt 
mkdir -p build
cd build

cmake \
  -DUSE_X264_H=1 -DNO_ESD=1 -DNO_SAMPLERATE=1 -DNO_QT4=1 \
  -DNO_ARTS=1  -DUSE_JACK_H=0 -DUSE_ESD_H=0 \
  -DCMAKE_INSTALL_PREFIX:STRING="/usr" \
  -DAVIDEMUX_SOURCE_DIR=$(cd .. ; pwd) \
  -DAVIDEMUX_CORECONFIG_DIR=$(cd .. ; pwd)/build/config \
  -DCMAKE_CXX_FLAGS:STRING="-O2 -march=i486 -mtune=i686" \
  -DCMAKE_C_FLAGS:STRING="-O2 -march=i486 -mtune=i686" \
  ..
  
make || return 1
make install DESTDIR=$dest
 
# plugin build expects libraries to be already installed; we fake a prefix
# in build/ by symlinking all libraries to build/lib/
#mkdir -p lib
#cd lib
#find $src/build/avidemux -name '*.so*' | xargs ln -sft . || return 1

#cd ../../plugins
cd ..
mkdir -p build_plugins
cd build_plugins
  cmake \
  -DCMAKE_CXX_FLAGS:STRING="-O2 -march=i686 -mtune=i686" \
  -DCMAKE_C_FLAGS:STRING="-O2 -march=i686 -mtune=i686" \
  -DCMAKE_INSTALL_PREFIX="/usr" \
  -DAVIDEMUX_SOURCE_DIR=$(cd .. ; pwd) \
  -DAVIDEMUX_CORECONFIG_DIR=$(cd .. ; pwd)/build/config \
  -DAVIDEMUX_INSTALL_PREFIX=$(cd .. ; pwd)/build \
  ../plugins || return 1
make || return 1       
make install DESTDIR=$dest

cd $dest/usr/lib/
ln -s ADM_plugins/videoEncoder/libADM_vidEnc_xvid.so libADM_vidEnc_xvid.so
ln -s ADM_plugins/videoEncoder/libADM_vidEnc_x264.so libADM_vidEnc_x264.so

rm -rf $dest/usr/local/

install -D -m644 $src/avidemux2.desktop $dest/usr/share/applications/avidemux.desktop
install -D -m644 $src/man/avidemux.1 $dest/usr/man/man1/avidemux.1

# Copy icons to the right place
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps
mv $src/"$softname"_icon.png $dest/usr/share/icons/hicolor/64x64/apps/$softname.png

mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
convert $dest/usr/share/icons/hicolor/64x64/apps/$softname.png -resize 48x48 $dest/usr/share/icons/hicolor/48x48/apps/$softname.png
 
# add 'default' files
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
       AUTHORS COPYING README TODO \
      $dest/usr/doc/$softname-$softversion
	
#  strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,cxxlibs|gcc-g++,e2fsprogs,expat,fontconfig,freetype,\
gcc,glib2,gtk+2,libICE,libSM,libX11,libXau,libXcomposite,libXcursor,\
libXdamage,libXdmcp,libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,\
libXv,libpng,libxcb,libxml2,pango,pixman,sdl,x264,xcb-util,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/avidemux/source/build-avidemux.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
